==> gradle-9.1.0-20250910012751+0000-src.zip: gradle-9.1.0-20250910012751+0000/testing/integ-test/build.gradle.kts <==
plugins {
    id("gradlebuild.internal.java")
}

description = "Integration tests which don't fit anywhere else - should probably be split up"

dependencies {
    integTestImplementation(projects.baseServices)
    integTestImplementation(projects.buildOption)
    integTestImplementation(projects.enterpriseOperations)
    integTestImplementation(projects.native)
    integTestImplementation(projects.logging)
    integTestImplementation(projects.processServices)
    integTestImplementation(projects.coreApi)
    integTestImplementation(projects.resources)
    integTestImplementation(projects.persistentCache)
    integTestImplementation(projects.dependencyManagement)
    integTestImplementation(projects.gradleCliMain)
    integTestImplementation(projects.launcher)
    integTestImplementation(projects.idePlugins)
    integTestImplementation(libs.groovy)
    integTestImplementation(libs.slf4jApi)
    integTestImplementation(libs.guava)
    integTestImplementation(libs.ant)
    integTestImplementation(libs.jsoup)

    integTestImplementation(libs.samplesCheck) {
        exclude(group = "org.codehaus.groovy", module = "groovy-all")
    }
    integTestImplementation(testFixtures(projects.modelReflect))

    crossVersionTestImplementation(projects.baseServices)
    crossVersionTestImplementation(projects.core)
    crossVersionTestImplementation(projects.pluginsApplication)
    crossVersionTestImplementation(projects.platformJvm)
    crossVersionTestImplementation(projects.languageJvm)
    crossVersionTestImplementation(projects.languageJava)
    crossVersionTestImplementation(projects.languageGroovy)
    crossVersionTestImplementation(projects.logging)
    crossVersionTestImplementation(projects.scala)
    crossVersionTestImplementation(projects.ear)
    crossVersionTestImplementation(projects.war)
    crossVersionTestImplementation(projects.testingJvm)
    crossVersionTestImplementation(projects.ide)
    crossVersionTestImplementation(projects.idePlugins)
    crossVersionTestImplementation(projects.codeQuality)
    crossVersionTestImplementation(projects.signing)
    crossVersionTestImplementation(projects.functional)

    integTestImplementation(testFixtures(projects.core))
    integTestImplementation(testFixtures(projects.scala))
    integTestImplementation(testFixtures(projects.platformNative))
    integTestImplementation(libs.jgit)

    integTestDistributionRuntimeOnly(projects.distributionsFull)
    crossVersionTestDistributionRuntimeOnly(projects.distributionsFull)
}

testFilesCleanup.reportOnly = true
tasks.isolatedProjectsIntegTest {
    enabled = false
}

==> gradle-9.5.0-20260222004246+0000-src.zip: gradle-9.5.0-20260222004246+0000/testing/integ-test/build.gradle.kts <==
plugins {
    id("gradlebuild.internal.java")
}

description = "Integration tests which don't fit anywhere else - should probably be split up"

dependencies {
    integTestImplementation(projects.baseServices)
    integTestImplementation(projects.buildOption)
    integTestImplementation(projects.coreApi)
    integTestImplementation(projects.dependencyManagement)
    integTestImplementation(projects.enterpriseOperations)
    integTestImplementation(projects.gradleCliMain)
    integTestImplementation(projects.idePlugins)
    integTestImplementation(projects.launcher)
    integTestImplementation(projects.logging)
    integTestImplementation(projects.native)
    integTestImplementation(projects.persistentCache)
    integTestImplementation(projects.processServices)
    integTestImplementation(projects.resources)
    integTestImplementation(libs.ant)
    integTestImplementation(libs.groovy)
    integTestImplementation(libs.guava)
    integTestImplementation(libs.jgit)
    integTestImplementation(libs.jsoup)
    integTestImplementation(libs.slf4jApi)
    integTestImplementation(testLibs.samplesCheck) {
        exclude(group = "org.codehaus.groovy", module = "groovy-all")
    }
    integTestImplementation(testFixtures(projects.core))
    integTestImplementation(testFixtures(projects.modelReflect))
    integTestImplementation(testFixtures(projects.platformNative))
    integTestImplementation(testFixtures(projects.scala))

    integTestDistributionRuntimeOnly(projects.distributionsFull)

    crossVersionTestImplementation(projects.baseServices)
    crossVersionTestImplementation(projects.codeQuality)
    crossVersionTestImplementation(projects.core)
    crossVersionTestImplementation(projects.ear)
    crossVersionTestImplementation(projects.functional)
    crossVersionTestImplementation(projects.ide)
    crossVersionTestImplementation(projects.idePlugins)
    crossVersionTestImplementation(projects.internalIntegTesting)
    crossVersionTestImplementation(projects.languageGroovy)
    crossVersionTestImplementation(projects.languageJava)
    crossVersionTestImplementation(projects.languageJvm)
    crossVersionTestImplementation(projects.logging)
    crossVersionTestImplementation(projects.platformJvm)
    crossVersionTestImplementation(projects.pluginsApplication)
    crossVersionTestImplementation(projects.scala)
    crossVersionTestImplementation(projects.signing)
    crossVersionTestImplementation(projects.testingJvm)
    crossVersionTestImplementation(projects.war)

    crossVersionTestDistributionRuntimeOnly(projects.distributionsFull)
}

testFilesCleanup.reportOnly = true
tasks.isolatedProjectsIntegTest {
    enabled = false
}

errorprone {
    nullawayEnabled = true
}
